@@ -57,12 +57,11 @@ type InternalConfig struct {
 	// Server mode?
 	Running bool
 
-	Quiet             bool
-	Verbose           bool
-	Clock             string
-	Watch             bool
-	DisableLiveReload bool
-	LiveReloadPort    int
+	Quiet          bool
+	Verbose        bool
+	Clock          string
+	Watch          bool
+	LiveReloadPort int
 }
 
 // All non-params config keys for language.
@@ -242,7 +241,7 @@ func (c *Config) CompileConfig(logger loggers.Logger) error {
 		kind = strings.ToLower(kind)
 		if kind == "taxonomyterm" {
 			// Legacy config.
-			kind = "term"
+			kind = "taxonomy"
 		}
 		disabledKinds[kind] = true
 	}
@@ -454,6 +453,9 @@ type RootConfig struct {
 	// Disable the injection of the Hugo generator tag on the home page.
 	DisableHugoGeneratorInject bool
 
+	// Disable live reloading in server mode.
+	DisableLiveReload bool
+
 	// Enable replacement in Pages' Content of Emoji shortcodes with their equivalent Unicode characters.
 	// <docsmeta>{"identifiers": ["Content", "Unicode"] }</docsmeta>
 	EnableEmoji bool
